@@ -1,9 +1,8 @@
-from fastapi import Request, HTTPException
+from fastapi import HTTPException, Request
 from fastapi.responses import JSONResponse
 
 from ..routes.response import return_response
 
-
 __all__ = ("http_exception_handler",)
 
 
