@@ -10,7 +10,7 @@ def filters_mapper(
     columns = filter_item.get("columns")
     columns_type = filter_item.get("type", "select")
 
-    if columns_type == "select":
+    if columns_type in {"select", "select_array"}:
         distinct_names_query = []
         for column in columns:
             query = db.query(
@@ -26,9 +26,16 @@ def filters_mapper(
                 query.filter(*pre_conditions, *conditions).distinct()
             )
 
-        values = list(
-            map(lambda x: x[0], db.execute(union(*distinct_names_query)).fetchall())
-        )
+        values = []
+        db_values = list(map(lambda x: x[0], db.execute(union(*distinct_names_query)).fetchall()))
+        if columns_type == "select_array":
+            for db_value in db_values:
+                if isinstance(db_value, list):
+                    values.extend(db_value)
+        else:
+            if isinstance(db_values, list):
+                values.extend(db_values)
+
         enum = filter_item.get("enum")
         labels = filter_item.get("labels", {})
         items = [
@@ -39,7 +46,7 @@ def filters_mapper(
             for value in values
             if value is not None
         ]
-        items = sorted(items, key=lambda x: x.get("value"))
+        items = sorted(items, key=lambda x: x.get("label"))
     elif columns_type in ["number", "date"]:
         main_query = db.query(
             func.least(*list(map(func.min, columns))),
@@ -79,7 +86,7 @@ def get_filters_value(
         filter_type = filter_item.get("type")
         filter_name = filter_item.get("name")
         if filter_mapping_result is not None:
-            if filter_type == "select":
+            if filter_type in {"select", "select_array"}:
                 available_filters.append(
                     {
                         "label": filter_label,
