@@ -7,7 +7,7 @@ from sqlalchemy import Text, and_, cast, func, literal, or_
 __all__ = ("make_condition",)
 
 
-def select_condition_maker(filter_item: dict, values: list):
+def select_condition_maker(filter_item: dict, values: list, array_mode: bool):
     columns = filter_item.get("columns", [])
     columns_logic = filter_item.get("columns_logic", "or")
     case_insensitive = filter_item.get("case_insensitive", False)
@@ -48,9 +48,17 @@ def select_condition_maker(filter_item: dict, values: list):
             # detect string columns via their python_type
             is_str_col = getattr(getattr(col, "type", None), "python_type", None) is str
             if case_insensitive and is_str_col:
-                conditions.append(func.lower(col).in_(processed_values))
+                if array_mode:
+                    lower_col_array = func.array(select(func.lower(func.unnest(col))).scalar_subquery())
+                    lower_vals_array = array([v.lower() for v in processed_values], type_=ARRAY(Text()))
+                    conditions.append(lower_col_array.op('&&')(lower_vals_array))
+                else:
+                    conditions.append(func.lower(col).in_(processed_values))
             else:
-                conditions.append(col.in_(processed_values))
+                if array_mode:
+                    conditions.append(col.op("&&")(literal(processed_values)))
+                else:
+                    conditions.append(col.in_(processed_values))
 
     # if no conditions, return a no-op true clause
     if not conditions:
@@ -105,10 +113,11 @@ def date_condition_maker(filter_item: dict, values: dict):
 def make_condition(filter_item: dict, values: Any):
     columns_type = filter_item.get("type", "select")
 
-    if columns_type == "select":
+    if columns_type in {"select", "select_array"}:
         return select_condition_maker(
             filter_item=filter_item,
             values=values,
+            array_mode=columns_type == "select_array",
         )
     elif columns_type == "number":
         return number_condition_maker(
