@@ -1,6 +1,10 @@
 from passlib.context import CryptContext
 
-pwd_cxt = CryptContext(schemes=["bcrypt"], deprecated="auto")
+pwd_cxt = CryptContext(
+    schemes=["argon2", "bcrypt"],
+    deprecated=["bcrypt"],
+    bcrypt__truncate_error=False,
+)
 
 
 __all__ = ("Hash",)
@@ -15,3 +19,8 @@ class Hash:
     @staticmethod
     def verify(plain_password: str, hashed_password: str):
         return pwd_cxt.verify(plain_password, hashed_password)
+
+    @staticmethod
+    def needs_update(hashed_password: str):
+        return pwd_cxt.needs_update(hashed_password)
+    
\ No newline at end of file
